@@ -2,14 +2,20 @@ package DateTime::Duration;
 
 use strict;
 use warnings;
+use namespace::autoclean;
 
-our $VERSION = '1.31';
+our $VERSION = '1.37';
 
 use Carp ();
 use DateTime;
 use DateTime::Helpers;
 use DateTime::Types;
-use Params::CheckCompiler qw( compile );
+use Params::ValidationCompiler qw( validation_for );
+
+BEGIN {
+    my $has = eval { require Sub::Util; 1 };
+    sub HAS_SUB_UTIL () {$has}
+}
 
 use overload (
     fallback => 1,
@@ -45,8 +51,8 @@ my @all_units = qw( months days minutes seconds nanoseconds );
         nanoseconds
     );
 
-    my $check = compile(
-        name   => '_check_new_params',
+    my $check = validation_for(
+        ( HAS_SUB_UTIL ? ( name => '_check_new_params' ) : () ),
         params => {
             %units,
             end_of_month => {
@@ -338,7 +344,7 @@ DateTime::Duration - Duration objects for date math
 
 =head1 VERSION
 
-version 1.31
+version 1.37
 
 =head1 SYNOPSIS
 
@@ -628,7 +634,7 @@ I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT AND LICENCE
+=head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2016 by Dave Rolsky.
 
