@@ -2,10 +2,11 @@ package DateTime::LeapSecond;
 
 use strict;
 use warnings;
+use namespace::autoclean;
 
-our $VERSION = '1.31';
+our $VERSION = '1.37';
 
-use vars qw( @RD @LEAP_SECONDS %RD_LENGTH );
+our ( @RD, @LEAP_SECONDS, %RD_LENGTH );
 
 use DateTime;
 
@@ -109,6 +110,7 @@ sub _initialize {
             2009  Jan. 1  +1
             2012  Jun. 1  +1
             2015  Jul. 1  +1
+            2017  Jan. 1  +1
             )
     );
 }
@@ -131,7 +133,7 @@ DateTime::LeapSecond - leap seconds table and utilities
 
 =head1 VERSION
 
-version 1.31
+version 1.37
 
 =head1 SYNOPSIS
 
@@ -192,7 +194,7 @@ I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT AND LICENCE
+=head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2016 by Dave Rolsky.
 
